@@ -1,5 +1,7 @@
 /*
- *  Copyright (C) 2007 aCaB <acab@clamav.net>
+ *  Copyright (C) 2007-2008 Sourcefire Inc.
+ *
+ *  Authors: Alberto Wu
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -20,5 +22,5 @@
 #define __NSIS_H
 
 #include "others.h"
-int cli_scannulsft(int desc, cli_ctx *ctx, off_t offset);
+int cli_scannulsft(cli_ctx *ctx, off_t offset);
 #endif
